@@ -30,12 +30,25 @@ using System.Collections;
 
 namespace Beagle.Daemon {
 
+	public delegate void IQueryableChangedHandler (IQueryable source,
+						       IQueryableChangeData changeData);
+
 	public interface IQueryable {
 
-		String Name { get; }
+		event IQueryableChangedHandler ChangedEvent;
+
+		void Start ();
 
 		bool AcceptQuery (QueryBody body);
 
-		void DoQuery (QueryBody body, IQueryResult queryResult);
+		void DoQuery (QueryBody body,
+			      IQueryResult queryResult,
+			      IQueryableChangeData data);
+
+		string GetHumanReadableStatus ();
+	}
+
+	public interface IQueryableChangeData { 
+	
 	}
 }
